pub struct Line<T> {
pub inner: T,
}Expand description
Single-line T followed by a line break: hello\nworld
Fields
inner: TTrait Implementations
Sourceimpl<'s, T> Inpt<'s> for Line<T>where
Self: 's,
T: Inpt<'s>,
impl<'s, T> Inpt<'s> for Line<T>where
Self: 's,
T: Inpt<'s>,
Sourcefn step(
text: &'s str,
end: bool,
trimmed: CharClass,
guard: &mut RecursionGuard,
) -> InptStep<'s, Self>
fn step( text: &'s str, end: bool, trimmed: CharClass, guard: &mut RecursionGuard, ) -> InptStep<'s, Self>
Consume a token of this type from the given text if possible, returning an error if not.
If
end is false, all remaining text should also be returned. Otherwise the text should be
consumed entirely. All text must be trimmed with the given CharClass (typically but not
always returned from Inpt::default_trim) before being passed to this function. Read moreSourcefn default_trim(inherited: CharClass) -> CharClass
fn default_trim(inherited: CharClass) -> CharClass
Determine the class of characters which this type would like trimmed off of any text before parsing.
This is inherited from the parent type if not otherwise defined.
impl<T: Copy> Copy for Line<T>
impl<T: Eq> Eq for Line<T>
impl<T> StructuralPartialEq for Line<T>